@@ -26,15 +26,19 @@ def scrape_tweets(class_name: str, query=None, username=None, limit=100):
     # Run
     twint.run.Search(c)
 
-    os.makedirs("content/data", exist_ok=True)
+    os.makedirs("data", exist_ok=True)
     with open("tmp.txt", "r") as f:
         lines = f.readlines()
 
+    count = 0
     with open(os.path.join("/content/data", class_name + ".txt"), "w") as f:
         for l in lines:
             idx = l.find(">")
             tweet = l[idx+2:-1]
-            f.write(tweet)
+            f.write(tweet+"\n")
+            count += 1
+            if count > limit:
+                break
 
     os.remove("tmp.txt")
 
